==> haskell-data-fix-0.3.4-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-fix
version:              0.3.4
visibility:           public
id:                   data-fix-0.3.4-KDmA6iBkIC24CMkxsVrZxF
key:                  data-fix-0.3.4-KDmA6iBkIC24CMkxsVrZxF
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  058935b26b7c0fcfdf59369914b520f3
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-fix
hs-libraries:         HSdata-fix-0.3.4-KDmA6iBkIC24CMkxsVrZxF
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-L2Cc1YdcpYH9U2sZW5osde

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-fix-0.3.4-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-fix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-fix
version:              0.3.4
visibility:           public
id:                   data-fix-0.3.4-La2oQS7pcm7JpGzyu04v7I
key:                  data-fix-0.3.4-La2oQS7pcm7JpGzyu04v7I
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  e700956a62a0a1dfbfd6e52a7ac4ae66
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-fix
hs-libraries:         HSdata-fix-0.3.4-La2oQS7pcm7JpGzyu04v7I
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-BOvwjrzThOwLkOxNRpkQTh

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
